@@ -1,7 +1,9 @@
 #!/usr/bin/env bash
 
+>&2 echo "WARNING: The zkcli.sh script has been deprecated in favour of the bin/solr equivalent commands."
+
 # You can override pass the following parameters to this script:
-# 
+#
 
 JVM="java"
 
@@ -23,6 +25,5 @@ solr_home="$sdir/../../solr"
 #...
 #   -DzkDigestCredentialsFile=/path/to/zkDigestCredentialsFile.properties
 #...
-PATH=$JAVA_HOME/bin:$PATH $JVM $SOLR_ZK_CREDS_AND_ACLS $ZKCLI_JVM_FLAGS -Dlog4j.configurationFile=$log4j_config -DsolrHome=$solr_home \
+PATH=$JAVA_HOME/bin:$PATH $JVM $SOLR_ZK_CREDS_AND_ACLS $ZKCLI_JVM_FLAGS -Dlog4j.configurationFile=$log4j_config -Dsolr.home=$solr_home \
 -classpath "$sdir/../../solr-webapp/webapp/WEB-INF/lib/*:$sdir/../../lib/ext/*:$sdir/../../lib/*" org.apache.solr.cloud.ZkCLI ${1+"$@"}
-
